@@ -1,15 +1,12 @@
 from datetime import datetime
 from typing import Optional, Any
 from uuid import uuid4
-
-from tracardi.service.storage.crud import StorageCrud
 from .context import Context
 from .entity import Entity
 from .metadata import Metadata
 from .profile import Profile
 from .session import Session
 from .time import Time
-from .value_object.storage_info import StorageInfo
 
 
 class Event(Entity):
@@ -44,17 +41,12 @@ class Event(Entity):
         self.profile = event.profile
         self.context = event.context
 
-    # Persistence
+    def is_persistent(self) -> bool:
+        if 'save' in self.context.config and isinstance(self.context.config['save'], bool):
+            return self.context.config['save']
+        else:
+            return True
 
-    def storage(self, **kwargs) -> StorageCrud:
-        return StorageCrud("event", Event, entity=self)
-
-    @staticmethod
-    def storage_info() -> StorageInfo:
-        return StorageInfo(
-            'event',
-            Event
-        )
 
     @staticmethod
     def new(data: dict) -> 'Event':
