@@ -1,10 +1,6 @@
-import copy
 import uuid
 from datetime import datetime
-from typing import Optional, Any, List, Union
-
-import tracardi
-
+from typing import Optional, Any, List, Union, Callable
 from tracardi_dot_notation.dot_accessor import DotAccessor
 from .entity import Entity
 from .metadata import Metadata
@@ -14,13 +10,9 @@ from .time import Time
 from .value_object.operation import Operation
 from .value_object.storage_info import StorageInfo
 from ..service.dot_notation_converter import DotNotationConverter
-from ..service.storage.collection_crud import CollectionCrud
-from ..service.storage.crud import StorageCrud
-
 from .profile_stats import ProfileStats
 from ..service.merger import merge
 from .segment import Segment
-from .segments import Segments
 from ..process_engine.tql.condition import Condition
 
 
@@ -77,7 +69,7 @@ class Profile(Entity):
 
         return disabled_profiles
 
-    async def segment(self, event_types):
+    async def segment(self, event_types, load_segment_by_event_type):
 
         """
         This method mutates current profile. Loads segments and adds segments to current profile.
@@ -95,7 +87,7 @@ class Profile(Entity):
 
             # todo segments are loaded one by one - maybe it is possible to load it at once
             # todo segments are loaded event is they are disabled. It is checked later. Maybe we can filter it here.
-            segments = await Segments.storage().load_by('eventType', event_type)
+            segments = await load_segment_by_event_type(event_type)
 
             for segment in segments:
 
@@ -122,7 +114,7 @@ class Profile(Entity):
 
                     yield event_type, segment_id, msg
 
-    async def merge(self, limit=2000) -> Union['Profiles', None]:
+    async def merge(self, load_profiles_to_merge_callable: Callable, limit: int = 2000) -> Union['Profiles', None]:
 
         """
         This method mutates current profile.
@@ -138,14 +130,14 @@ class Profile(Entity):
         if len(merge_key_values) > 0:
 
             # Load all profiles that match merging criteria
-            existing_profiles = await tracardi.domain.value_object.operation.Operation.load_profiles_to_merge(
+            existing_profiles = await load_profiles_to_merge_callable(
                 merge_key_values,
                 limit=limit)
 
             # Filter only profiles that are not current profile and where not merged
             profiles_to_merge = [p for p in existing_profiles if p.id != self.id and p.active is True]
 
-            print('profiles_to_merge',profiles_to_merge)
+            print('profiles_to_merge', profiles_to_merge)
 
             # Are there any profiles to merge?
             if len(profiles_to_merge) > 0:
@@ -166,12 +158,14 @@ class Profile(Entity):
 
     def increase_visits(self, value=1):
         self.stats.visits += value
+        self.operation.update = True
 
     def increase_views(self, value=1):
         self.stats.views += value
+        self.operation.update = True
 
-    def storage(self) -> StorageCrud:
-        return StorageCrud("profile", Profile, entity=self, exclude={"operation": ...})
+    # def storage(self) -> StorageCrud:
+    #     return StorageCrud("profile", Profile, entity=self, exclude={"operation": ...})
 
     @staticmethod
     def storage_info() -> StorageInfo:
@@ -181,18 +175,18 @@ class Profile(Entity):
             exclude={"operation": ...}
         )
 
-    @staticmethod
-    async def load_current(id) -> 'Profile':
-
-        """
-        Loads current profile. If profile was merged then it loads merged profile.
-        """
-
-        entity = Entity(id=id)
-        profile = await entity.storage('profile').load(Profile)  # type: Profile
-        if profile is not None and profile.mergedWith is not None:
-            profile = await Profile.load_current(profile.mergedWith)
-        return profile
+    # @staticmethod
+    # async def load_current(id) -> 'Profile':
+    #
+    #     """
+    #     Loads current profile. If profile was merged then it loads merged profile.
+    #     """
+    #
+    #     entity = Entity(id=id)
+    #     profile = await StorageFor(entity).index('profile').load(Profile)  # type: Profile
+    #     if profile is not None and profile.mergedWith is not None:
+    #         profile = await Profile.load_current(profile.mergedWith)
+    #     return profile
 
     @staticmethod
     def new() -> 'Profile':
@@ -244,6 +238,3 @@ class Profiles(list):
             consents=consents,
             active=True
         )
-
-    def bulk(self) -> CollectionCrud:
-        return CollectionCrud("profile", self)
